CREATE SCHEMA Entwurf

-- Historie:
--
-- 29.06.2004 - 1.006 (1.009)
-- berarbeitung gem Dokument N0060
--
-- 03.09.2003 - 1.005 (1.008)
-- berarbeitung gem Dokument N0051
--
-- 31.05.2002 - 1.004 (1.007)
-- berarbeitung gem Dokument N0030
--
-- 12.09.2001 - 1.003 (1.004)
-- berarbeitung in Folge des nderungsantrags A0006
--
-- 11.12.2000 - 1.002 (1.002)
-- Symbolische Verweise integriert fr Netzknoten
--
-- 08.10.2000 - 1.001 (1.001)
-- Anbindung an die Schemata allgemeine Geometrieobjekte
-- und Grunderwerb
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Trasse (
   Trasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Trasse_ID) REFERENCES allgemeine_Eigenschaften,
   hat_Netzknoten
      INTEGER REFERENCES Strassennetz.Netzknoten_abstrakt
)

CREATE TABLE Achse (
   Achse_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Achse_ID) REFERENCES allgemeine_Eigenschaften,
   FOREIGN KEY (Achse_ID) REFERENCES Ausgangsdaten_QP,
   gehoert_zu_Trasse
      INTEGER NOT NULL REFERENCES Trasse
)

CREATE TABLE Achselement (
   Achselement_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Achselement_ID) REFERENCES allgemeine_Eigenschaften,
   Elementtyp
      INTEGER NOT NULL REFERENCES Achselementtyp,
   Anfangsstation_rechnerisch
      REAL NOT NULL, -- Meter
   Verwaltungsstation_Betriebskm
      REAL NOT NULL, -- Kilometer
   Laenge
      REAL NOT NULL, -- Meter
   Richtung
      REAL NOT NULL, -- Winkel
   Parameter
      REAL NOT NULL, -- Groesse
   CHECK ( Parameter >= 0 ),
   Radius_zu_Beginn
      REAL NOT NULL, -- Meter
   Radius_am_Ende
      REAL NOT NULL, -- Meter
   beginnt_bei_Achshauptpunkt
      INTEGER NOT NULL REFERENCES Achshauptpunkt,
   endet_bei_Achshauptpunkt
      INTEGER NOT NULL REFERENCES Achshauptpunkt,
   gehoert_zu_Achse
      INTEGER REFERENCES Achse
)

CREATE TABLE Achselementtyp (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Achselementtyp VALUES (1,'Gerade')
INSERT INTO Achselementtyp VALUES (2,'Kreisbogen, tangential')
INSERT INTO Achselementtyp VALUES (12,'Klothoide')

CREATE TABLE Achshauptpunkt (
   Achshauptpunkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Achshauptpunkt_ID) REFERENCES Geometrieschema.Punktobjekt_Modell
)

CREATE TABLE Kreuzungs_o_Einmuendungsplang (
   Kreuzungs_o_Einmuendgsplang_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Kreuzungs_o_Einmuendgsplang_ID) REFERENCES allgemeine_Eigenschaften,
   Netzknotennummer
      VARCHAR(7),
   Knotenpunktsform
      INTEGER REFERENCES Strassennetz.Knotenpunktsform,
   hat_DGM
      INTEGER REFERENCES DGM,
   hat_Achshauptpunkt
      INTEGER REFERENCES Achshauptpunkt
)

CREATE TABLE Kreuz_o_Einmplang__hat_Achse (
   Kreuzungs_o_Einmuendungsplang
      INTEGER NOT NULL REFERENCES Kreuzungs_o_Einmuendungsplang,
   Achse
      INTEGER NOT NULL REFERENCES Achse
)

CREATE TABLE Kreuz_o_Einmplg__h_Gradiente (
   Kreuzungs_o_Einmuendungsplang
      INTEGER NOT NULL REFERENCES Kreuzungs_o_Einmuendungsplang,
   Gradiente
      INTEGER NOT NULL REFERENCES Gradiente
)

CREATE TABLE DGM (
   DGM_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (DGM_ID) REFERENCES allgemeine_Eigenschaften
)

CREATE TABLE Laengsschnitt (
   Laengsschnitt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Laengsschnitt_ID) REFERENCES allgemeine_Eigenschaften,
   gehoert_zu_Achse
      INTEGER NOT NULL REFERENCES Achse,
   gehoert_zu_Trasse
      INTEGER NOT NULL REFERENCES Trasse
)

CREATE TABLE Laengsschnitt__hat_kreuz_Bauw (
   Laengsschnitt
      INTEGER NOT NULL REFERENCES Laengsschnitt,
   kreuzende_Bauwerke_o_baul_Anl
      INTEGER NOT NULL REFERENCES kreuzende_Bauwerke_o_baul_Anl
)

CREATE TABLE Gelaendehorizonte (
   Gelaendehorizonte_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Gelaendehorizonte_ID) REFERENCES Laengsschnittlinie,
   gehoert_zu_Laengsschnitt
      INTEGER NOT NULL REFERENCES Laengsschnitt
)

CREATE TABLE Gradiente (
   Gradiente_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Gradiente_ID) REFERENCES Laengsschnittlinie,
   gehoert_zu_Laengsschnitt
      INTEGER NOT NULL REFERENCES Laengsschnitt
)

CREATE TABLE kreuzende_Bauwerke_o_baul_Anl (
   kreuzde_Bauwerke_o_baul_Anl_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (kreuzde_Bauwerke_o_baul_Anl_ID) REFERENCES allgemeine_Eigenschaften,
   hat_Bauwerkseinzelheiten
      INTEGER REFERENCES Ingenieurbauwerke.Bauwerkseinzelheiten
)

CREATE TABLE kreuz_Bauwerk__hat_Schnittgeom (
   kreuzende_Bauwerke_o_baul_Anl
      INTEGER NOT NULL REFERENCES kreuzende_Bauwerke_o_baul_Anl,
   Schnittgeometrie
      INTEGER NOT NULL REFERENCES Schnittgeometrie
)

CREATE TABLE Schnittgeometrie (
   Schnittgeometrie_ID
      INTEGER NOT NULL PRIMARY KEY,
   Schnittstation
      REAL NOT NULL, -- Meter
   Schnitthoehe
      REAL NOT NULL, -- Meter
   Schnittwinkel_horizontal
      REAL NOT NULL, -- Winkel
   Laengsneigung_kreuzend_Bauwerk
      REAL NOT NULL -- Winkel
)

CREATE TABLE Schnittgeom__hat_Schnpolygone (
   Schnittgeometrie
      INTEGER NOT NULL REFERENCES Schnittgeometrie,
   Schnittpolygone
      INTEGER NOT NULL REFERENCES Schnittpolygone
)

CREATE TABLE Schnittgeom__hat_Mindabstpolyg (
   Schnittgeometrie
      INTEGER NOT NULL REFERENCES Schnittgeometrie,
   Mindestabstandspolygon
      INTEGER NOT NULL REFERENCES Mindestabstandspolygon
)

CREATE TABLE Schnittgeom__hat_Maxabstpolyg (
   Schnittgeometrie
      INTEGER NOT NULL REFERENCES Schnittgeometrie,
   Maximalabstandspolygon
      INTEGER NOT NULL REFERENCES Maximalabstandspolygon
)

CREATE TABLE Schnittpolygone (
   Schnittpolygone_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Schnittpolygone_ID) REFERENCES Polygon
)

CREATE TABLE Mindestabstandspolygon (
   Mindestabstandspolygon_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Mindestabstandspolygon_ID) REFERENCES Polygon
)

CREATE TABLE Maximalabstandspolygon (
   Maximalabstandspolygon_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Maximalabstandspolygon_ID) REFERENCES Polygon
)

CREATE TABLE Polygon (
   Polygon_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Polygon__hat_QP_Punkte (
   Polygon
      INTEGER NOT NULL REFERENCES Polygon,
   QP_Punkte
      INTEGER NOT NULL REFERENCES QP_Punkte,
   folgt_auf_QP_Punkte
      INTEGER REFERENCES QP_Punkte
)

CREATE TABLE Laengsschnittlinie (
   Laengsschnittlinie_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Laengsschnittlinie_ID) REFERENCES allgemeine_Eigenschaften,
   abs_Abstand
      FLOAT (16)
)

CREATE TABLE Laengsschnittl__hat_LS_Koor (
   Laengsschnittlinie
      INTEGER NOT NULL REFERENCES Laengsschnittlinie,
   LS_Koor
      INTEGER NOT NULL REFERENCES LS_Koor,
   folgt_auf_LS_Koor
      INTEGER REFERENCES LS_Koor
)

CREATE TABLE Laengsschnittlinie__hat_Breite (
   Laengsschnittlinie
      INTEGER NOT NULL REFERENCES Laengsschnittlinie,
   Breite
      INTEGER NOT NULL REFERENCES Breite
)

CREATE TABLE LS_Koor (
   LS_Koor_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (LS_Koor_ID) REFERENCES allgemeine_Eigenschaften,
   Station
      REAL NOT NULL, -- Meter
   Hoehe
      REAL NOT NULL, -- Meter
   folgt_auf_LS_Koor
      INTEGER REFERENCES Punktfolge
)

CREATE TABLE Punktfolge (
   Punktfolge_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Tangente_Gerade
      INTEGER NOT NULL REFERENCES Tangente_Gerade
)

CREATE TABLE Tangentenfolge (
   Tangentenfolge_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Ausrundung
      INTEGER REFERENCES Ausrundung
)

CREATE TABLE Ausrundung (
   Ausrundung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Ausrundungstyp
      INTEGER NOT NULL REFERENCES Ausrundungstyp,
   Ausrundungsparameter
      REAL NOT NULL, -- Groesse
   CHECK ( Ausrundungsparameter >= 0 )
)

CREATE TABLE Ausrundungstyp (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Ausrundungstyp VALUES (13,'Parabel 2. Grades')
INSERT INTO Ausrundungstyp VALUES (14,'Parabel 3. Grades mit langem Teil vor TS')
INSERT INTO Ausrundungstyp VALUES (15,'Parabel 3. Grades mit langem Teil hinter TS')

CREATE TABLE Tangente_Gerade (
   Tangente_Gerade_ID
      INTEGER NOT NULL PRIMARY KEY,
   folgt_auf_Tangente_Gerade
      INTEGER REFERENCES Tangentenfolge
)

CREATE TABLE Volumen_aus_QP (
   Volumen_aus_QP_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Volumen_aus_QP_ID) REFERENCES allgemeine_Eigenschaften,
   Station_1
      REAL NOT NULL, -- Meter
   Station_2
      REAL NOT NULL -- Meter
)

CREATE TABLE Oberflaeche (
   Oberflaeche_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Oberflaeche_ID) REFERENCES allgemeine_Eigenschaften,
   Art_der_Oberflaeche
      INTEGER NOT NULL,
   Station_1
      REAL NOT NULL, -- Meter
   Station_2
      REAL NOT NULL, -- Meter
   liegt_auf_Profillinie
      INTEGER NOT NULL REFERENCES Profillinien,
   beginnt_bei_QP_Punkt
      INTEGER NOT NULL REFERENCES QP_Punkte,
   endet_bei_QP_Punkt
      INTEGER NOT NULL REFERENCES QP_Punkte
)

CREATE TABLE Ausgangsdaten (
   Ausgangsdaten_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Ausgangsdaten__hat_Breite (
   Ausgangsdaten
      INTEGER NOT NULL REFERENCES Ausgangsdaten,
   Breite
      INTEGER NOT NULL REFERENCES Breite
)

CREATE TABLE Ausgangsdaten__hat_Querneigung (
   Ausgangsdaten
      INTEGER NOT NULL REFERENCES Ausgangsdaten,
   Querneigung
      INTEGER NOT NULL REFERENCES Querneigung
)

CREATE TABLE Ausgangsdaten__hat_Hoehenzuege (
   Ausgangsdaten
      INTEGER NOT NULL REFERENCES Ausgangsdaten,
   Hoehenzuege
      INTEGER NOT NULL REFERENCES Hoehenzuege
)

CREATE TABLE Trassenkoerper (
   Trassenkoerper_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Deckenbuch
      INTEGER REFERENCES Deckenbuch,
   gehoert_zu_Achse
      INTEGER NOT NULL REFERENCES Achse,
   gehoert_zu_Trasse
      INTEGER NOT NULL REFERENCES Trasse
)

CREATE TABLE Trassenkoerper__hat_Volumen (
   Trassenkoerper
      INTEGER NOT NULL REFERENCES Trassenkoerper,
   Volumen_aus_QP
      INTEGER NOT NULL REFERENCES Volumen_aus_QP
)

CREATE TABLE Trassenkoerper__hat_Oberfl (
   Trassenkoerper
      INTEGER NOT NULL REFERENCES Trassenkoerper,
   Oberflaeche
      INTEGER NOT NULL REFERENCES Oberflaeche
)

CREATE TABLE Trassenkoerper__hat_Ausgdaten (
   Trassenkoerper
      INTEGER NOT NULL REFERENCES Trassenkoerper,
   Ausgangsdaten
      INTEGER NOT NULL REFERENCES Ausgangsdaten
)

CREATE TABLE dynamisches_Querprofil (
   dynamisches_Querprofil_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_generellen_RQ_Code
      INTEGER NOT NULL REFERENCES RQ_Code,
   zu_Querprofil
      INTEGER NOT NULL REFERENCES Querprofil
)

CREATE TABLE dyn_Querprof__h_Zuordn_Ausgsd (
   dynamisches_Querprofil
      INTEGER NOT NULL REFERENCES dynamisches_Querprofil,
   Zuordnung_Ausgangsdaten
      INTEGER NOT NULL REFERENCES Zuordnung_Ausgangsdaten
)

CREATE TABLE dynam_Querprofil__lok_RQ_Code (
   dynamisches_Querprofil
      INTEGER NOT NULL REFERENCES dynamisches_Querprofil,
   RQ_Code
      INTEGER NOT NULL REFERENCES RQ_Code,
   folgt_auf_RQ_Code
      INTEGER REFERENCES RQ_Code
)

CREATE TABLE RQ_Code (
   RQ_Code_ID
      INTEGER NOT NULL PRIMARY KEY,
   RQ_Aufruf
      VARCHAR(255) NOT NULL
)

CREATE TABLE RQ_Code__hat_RQ_Code_Modul (
   RQ_Code
      INTEGER NOT NULL REFERENCES RQ_Code,
   RQ_Code_Modul
      INTEGER NOT NULL REFERENCES RQ_Code_Modul
)

CREATE TABLE RQ_Code_Modul (
   RQ_Code_Modul_ID
      INTEGER NOT NULL PRIMARY KEY,
   RQ_Modulname
      VARCHAR(255) NOT NULL,
   Code
      VARCHAR(255) NOT NULL
)

CREATE TABLE Zuordnung_Ausgangsdaten (
   Zuordnung_Ausgangsdaten_ID
      INTEGER NOT NULL PRIMARY KEY,
   Zuordnungsname
      VARCHAR(255) NOT NULL,
   hat_Ausgangsdaten_links_beide
      INTEGER NOT NULL REFERENCES Ausgangsdaten_QP,
   hat_Ausgangsdaten_rechts
      INTEGER REFERENCES Ausgangsdaten_QP
)

CREATE TABLE Ausgangsdaten_QP (
   Ausgangsdaten_QP_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Querprofil (
   Querprofil_ID
      INTEGER NOT NULL PRIMARY KEY,
   Station
      REAL NOT NULL, -- Meter
   hat_Schnittebene
      INTEGER REFERENCES Schnittebene,
   gehoert_zu_Trassenkoerper
      INTEGER REFERENCES Trassenkoerper
)

CREATE TABLE Querprofil__hat_Profillinien (
   Querprofil
      INTEGER NOT NULL REFERENCES Querprofil,
   Profillinien
      INTEGER NOT NULL REFERENCES Profillinien
)

CREATE TABLE Querprofil__hat_QP_Punkte (
   Querprofil
      INTEGER NOT NULL REFERENCES Querprofil,
   QP_Punkte
      INTEGER NOT NULL REFERENCES QP_Punkte
)

CREATE TABLE QP_Punkte (
   QP_Punkte_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (QP_Punkte_ID) REFERENCES allgemeine_Eigenschaften,
   Abstand_zur_Achse
      FLOAT (16) NOT NULL,
   Hoehe_NN
      FLOAT (16) NOT NULL
)

CREATE TABLE Profillinien (
   Profillinien_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Profillinien_ID) REFERENCES allgemeine_Eigenschaften,
   FOREIGN KEY (Profillinien_ID) REFERENCES Ausgangsdaten_QP,
   Horizont_Nummer
      INTEGER, -- Anzahl_zweistellig
   CHECK ( ( Horizont_Nummer >= 0 ) AND ( Horizont_Nummer <= 99 ) ),
   Art
      INTEGER NOT NULL REFERENCES Art_des_Horizonts,
   begrenzt_Volumen_aus_QP
      INTEGER REFERENCES Volumen_aus_QP
)

CREATE TABLE Profillinien__hat_QP_Punkte (
   Profillinien
      INTEGER NOT NULL REFERENCES Profillinien,
   QP_Punkte
      INTEGER NOT NULL REFERENCES QP_Punkte,
   folgt_auf_QP_Punkte
      INTEGER REFERENCES QP_Punkte
)

CREATE TABLE Art_des_Horizonts (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Art_des_Horizonts VALUES (66,'Horizont')
INSERT INTO Art_des_Horizonts VALUES (54,'geschlossene Linie')

CREATE TABLE Schnittebene (
   Schnittebene_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Schnittebene__hat_SNT_Punkte (
   Schnittebene
      INTEGER NOT NULL REFERENCES Schnittebene,
   SNT_Punkt
      INTEGER NOT NULL REFERENCES SNT_Punkt,
   folgt_auf_SNT_Punkt
      INTEGER REFERENCES SNT_Punkt
)

CREATE TABLE SNT_Punkt (
   SNT_Punkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Abstand
      REAL NOT NULL, -- Meter
   Richtungsaenderung
      FLOAT (16) NOT NULL,
   korrespondierende_Achse
      VARCHAR(255),
   Naeherungsstation
      REAL -- Meter
)

CREATE TABLE Deckenbuch (
   Deckenbuch_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Deckenbuch_ID) REFERENCES allgemeine_Eigenschaften,
   Station_1
      REAL NOT NULL, -- Meter
   Station_2
      REAL NOT NULL -- Meter
)

CREATE TABLE Deckenb__hat_Spur_a_Ausgangsd (
   Deckenbuch
      INTEGER NOT NULL REFERENCES Deckenbuch,
   Spur_aus_Ausgangsdaten
      INTEGER NOT NULL REFERENCES Spur_aus_Ausgangsdaten,
   folgt_auf_Spur_aus_Ausgdaten
      INTEGER REFERENCES Spur_aus_Ausgangsdaten
)

CREATE TABLE Spur_aus_Ausgangsdaten (
   Spur_aus_Ausgangsdaten_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Spur_aus_Ausgangsdaten_ID) REFERENCES allgemeine_Eigenschaften,
   hat_Querneigung
      INTEGER REFERENCES Querneigung,
   hat_Breite
      INTEGER NOT NULL REFERENCES Breite,
   hat_Hoehenzuege
      INTEGER REFERENCES Hoehenzuege,
   hat_Hochbord
      INTEGER REFERENCES Hochbord
)

CREATE TABLE Breite (
   Breite_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Breite_ID) REFERENCES allgemeine_Eigenschaften,
   FOREIGN KEY (Breite_ID) REFERENCES Ausgangsdaten_QP
)

CREATE TABLE Breite__hat_BR_Punkt (
   Breite
      INTEGER NOT NULL REFERENCES Breite,
   BR_Punkt
      INTEGER NOT NULL REFERENCES BR_Punkt,
   folgt_auf_BR_Punkt
      INTEGER REFERENCES BR_Punkt
)

CREATE TABLE BR_Punktfolge (
   BR_Punktfolge_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Aufweitg_Verbreit_Verbind
      INTEGER NOT NULL REFERENCES Aufweitung_Verbreit_Verbind
)

CREATE TABLE BR_Punkt (
   BR_Punkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Breite
      REAL, -- Meter
   Station
      REAL NOT NULL, -- Meter
   hat_Abstand_Achse_Achse
      INTEGER REFERENCES Abstand_Achse_Achse,
   hat_Abstand_Achse_Linie
      INTEGER REFERENCES Abstand_Achse_Linie,
   folgt_auf_BR_Punkt
      INTEGER REFERENCES BR_Punktfolge,
   bez_auf_Spur_aus_Ausgangsdaten
      INTEGER REFERENCES Spur_aus_Ausgangsdaten,
   gehoert_zu_Breite
      INTEGER NOT NULL REFERENCES Breite,
   CHECK ( (Breite IS NOT NULL AND hat_Abstand_Achse_Achse IS NULL AND hat_Abstand_Achse_Linie IS NULL) OR (Breite IS NULL AND hat_Abstand_Achse_Achse IS NOT NULL AND hat_Abstand_Achse_Linie IS NULL) OR (Breite IS NULL AND hat_Abstand_Achse_Achse IS NULL AND hat_Abstand_Achse_Linie IS NOT NULL) )
)

CREATE TABLE Aufweitung_Verbreit_Verbind (
   Aufweitung_Verbreit_Verbind_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_der_Verziehung
      INTEGER NOT NULL REFERENCES Art_der_Verziehung,
   Tangentenlaenge
      REAL -- Meter
)

CREATE TABLE Art_der_Verziehung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Art_der_Verziehung VALUES (1,'Parabelfolge 2. Grades')
INSERT INTO Art_der_Verziehung VALUES (2,'Bogenfolge')
INSERT INTO Art_der_Verziehung VALUES (3,'Parabelfolge 2. Grades / Zwischengerade')
INSERT INTO Art_der_Verziehung VALUES (4,'Gerade')
INSERT INTO Art_der_Verziehung VALUES (5,'Bezug auf Referenzobjekt')

CREATE TABLE Abstand_Achse_Achse (
   Abstand_Achse_Achse_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Abstand_Achse_Achse_ID) REFERENCES Ausgangsdaten_QP,
   Naeherungsstation_auf_zw_Achse
      REAL NOT NULL, -- Meter
   hat_Lage_der_Knicklinie
      INTEGER NOT NULL REFERENCES Lage_der_Knicklinie,
   hat_zweite_Achse
      INTEGER NOT NULL REFERENCES Achse
)

CREATE TABLE Abstand_Achse_Linie (
   Abstand_Achse_Linie_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Abstand_Achse_Linie_ID) REFERENCES Geometrieschema.Linienobjekt_Modell
)

CREATE TABLE Lage_der_Knicklinie (
   Lage_der_Knicklinie_ID
      INTEGER NOT NULL PRIMARY KEY,
   Typ_der_Knicklinie
      INTEGER NOT NULL REFERENCES Typ_der_Knicklinie,
   Breite
      REAL -- Meter
)

CREATE TABLE Typ_der_Knicklinie (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Typ_der_Knicklinie VALUES (1,'Parallele / Breite zur zweiten Achse')
INSERT INTO Typ_der_Knicklinie VALUES (2,'Parallele / Breite zur Achse')
INSERT INTO Typ_der_Knicklinie VALUES (3,'Mittig mit Abstand zur Knicklinie')

CREATE TABLE Hoehenzuege (
   Hoehenzuege_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Hoehenzuege_ID) REFERENCES allgemeine_Eigenschaften,
   FOREIGN KEY (Hoehenzuege_ID) REFERENCES Ausgangsdaten_QP
)

CREATE TABLE Hoehenzuege__hat_HZ_Punkte (
   Hoehenzuege
      INTEGER NOT NULL REFERENCES Hoehenzuege,
   HZ_Punkt
      INTEGER NOT NULL REFERENCES HZ_Punkt,
   folgt_auf_HZ_Punkt
      INTEGER REFERENCES HZ_Punkt
)

CREATE TABLE HZ_Punkt (
   HZ_Punkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Station
      REAL NOT NULL, -- Meter
   Hoehe_fest
      REAL, -- Meter
   hat_Hoehe_Gradiente
      INTEGER REFERENCES Hoehe_Gradiente,
   hat_Hoehe_Linie
      INTEGER REFERENCES Hoehe_Linie,
   gehoert_zu_Hoehenzug
      INTEGER NOT NULL REFERENCES Hoehenzuege,
   CHECK ( (Hoehe_fest IS NOT NULL AND hat_Hoehe_Gradiente IS NULL AND hat_Hoehe_Linie IS NULL) OR (Hoehe_fest IS NULL AND hat_Hoehe_Gradiente IS NOT NULL AND hat_Hoehe_Linie IS NULL) OR (Hoehe_fest IS NULL AND hat_Hoehe_Gradiente IS NULL AND hat_Hoehe_Linie IS NOT NULL) )
)

CREATE TABLE Hoehe_Gradiente (
   Hoehe_Gradiente_ID
      INTEGER NOT NULL PRIMARY KEY,
   Naeherungsstation_Gradiente
      REAL NOT NULL, -- Meter
   hat_Gradiente
      INTEGER NOT NULL REFERENCES Gradiente
)

CREATE TABLE Hoehe_Linie (
   Hoehe_Linie_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Hoehe_Linie_ID) REFERENCES Geometrieschema.Linienobjekt_Modell
)

CREATE TABLE Querneigung (
   Querneigung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Querneigung_ID) REFERENCES allgemeine_Eigenschaften,
   FOREIGN KEY (Querneigung_ID) REFERENCES Ausgangsdaten_QP
)

CREATE TABLE Querneigung__hat_QN_Punkte (
   Querneigung
      INTEGER NOT NULL REFERENCES Querneigung,
   QN_Punkt
      INTEGER NOT NULL REFERENCES QN_Punkt,
   folgt_auf_QN_Punkt
      INTEGER REFERENCES QN_Punkt
)

CREATE TABLE Querneigungswechsel (
   Querneigungswechsel_ID
      INTEGER NOT NULL PRIMARY KEY,
   Verziehungsform
      INTEGER NOT NULL REFERENCES Verziehungsform
)

CREATE TABLE Verziehungsform (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Verziehungsform VALUES (0,'reserviert')
INSERT INTO Verziehungsform VALUES (1,'normale Verziehung')
INSERT INTO Verziehungsform VALUES (2,'Verziehung mit Gratlinie (Schrgverwindung)')

CREATE TABLE QN_Punkt (
   QN_Punkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Station
      REAL NOT NULL, -- Meter
   Querneigung
      REAL, -- Prozent
   automatische_Berechnung
      INTEGER REFERENCES Logical_Types.Boolean,
   folgt_auf_QN_Punkt
      INTEGER REFERENCES Querneigungswechsel,
   gehoert_zu_Querneigung
      INTEGER NOT NULL REFERENCES Querneigung
)

CREATE TABLE Hochbord (
   Hochbord_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Hochbord_ID) REFERENCES allgemeine_Eigenschaften,
   FOREIGN KEY (Hochbord_ID) REFERENCES Ausgangsdaten_QP
)

CREATE TABLE Hochbord__hat_HB_Punkte (
   Hochbord
      INTEGER NOT NULL REFERENCES Hochbord,
   HB_Punkt
      INTEGER NOT NULL REFERENCES HB_Punkt,
   folgt_auf_HB_Punkt
      INTEGER REFERENCES HB_Punkt
)

CREATE TABLE Hochbord__hat_HB_Neigung (
   Hochbord
      INTEGER NOT NULL REFERENCES Hochbord,
   HB_Neigung
      INTEGER NOT NULL REFERENCES HB_Neigung
)

CREATE TABLE HB_Punkt (
   HB_Punkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Station
      REAL NOT NULL, -- Meter
   Differenzhoehe
      REAL NOT NULL, -- Meter
   gehoert_zu_Hochbord
      INTEGER NOT NULL REFERENCES Hochbord
)

CREATE TABLE HB_Neigung (
   HB_Neigung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Station
      REAL NOT NULL, -- Meter
   Neigungswinkel
      REAL NOT NULL, -- Groesse
   CHECK ( Neigungswinkel >= 0 )
)

CREATE TABLE Achsstationswerte (
   Achsstationswerte_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Achsstationswerte_ID) REFERENCES allgemeine_Eigenschaften,
   FOREIGN KEY (Achsstationswerte_ID) REFERENCES Ausgangsdaten_QP
)

CREATE TABLE Achsstationswerte__hat_AW_Koor (
   Achsstationswerte
      INTEGER NOT NULL REFERENCES Achsstationswerte,
   AW_Koor
      INTEGER NOT NULL REFERENCES AW_Koor,
   folgt_auf_AW_Koor
      INTEGER REFERENCES AW_Koor
)

CREATE TABLE AW_Koor (
   AW_Koor_ID
      INTEGER NOT NULL PRIMARY KEY,
   Station
      REAL NOT NULL, -- Meter
   Character_Kennwert
      VARCHAR(255),
   Integer_Kennwert
      INTEGER,
   Real_Kennwert
      REAL,
   Boolean_Kennwert
      INTEGER REFERENCES Logical_Types.Boolean,
   CHECK ( (Character_Kennwert IS NOT NULL AND Integer_Kennwert IS NULL AND Real_Kennwert IS NULL AND Boolean_Kennwert IS NULL) OR (Character_Kennwert IS NULL AND Integer_Kennwert IS NOT NULL AND Real_Kennwert IS NULL AND Boolean_Kennwert IS NULL) OR (Character_Kennwert IS NULL AND Integer_Kennwert IS NULL AND Real_Kennwert IS NOT NULL AND Boolean_Kennwert IS NULL) OR (Character_Kennwert IS NULL AND Integer_Kennwert IS NULL AND Real_Kennwert IS NULL AND Boolean_Kennwert IS NOT NULL) )
)

CREATE TABLE Entwurfsparameter (
   Entwurfsparameter_ID
      INTEGER NOT NULL PRIMARY KEY,
   Strassenkategorie
      INTEGER REFERENCES Strassenkategorie_RAS_L,
   gehoert_zu_Achse
      INTEGER NOT NULL REFERENCES Achse,
   gehoert_zu_Trasse
      INTEGER NOT NULL REFERENCES Trasse
)

CREATE TABLE Entwurfsparam__hat_Geschwband (
   Entwurfsparameter
      INTEGER NOT NULL REFERENCES Entwurfsparameter,
   Geschwindigkeitsband
      INTEGER NOT NULL REFERENCES Geschwindigkeitsband
)

CREATE TABLE Strassenkategorie_RAS_L (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Strassenkategorie_RAS_L VALUES (11,'A-I')
INSERT INTO Strassenkategorie_RAS_L VALUES (12,'A-II')
INSERT INTO Strassenkategorie_RAS_L VALUES (13,'A-III')
INSERT INTO Strassenkategorie_RAS_L VALUES (14,'A-IV')
INSERT INTO Strassenkategorie_RAS_L VALUES (15,'A-V')
INSERT INTO Strassenkategorie_RAS_L VALUES (16,'A-VI')
INSERT INTO Strassenkategorie_RAS_L VALUES (21,'B-I')
INSERT INTO Strassenkategorie_RAS_L VALUES (22,'B-II')
INSERT INTO Strassenkategorie_RAS_L VALUES (23,'B-III')
INSERT INTO Strassenkategorie_RAS_L VALUES (24,'B-IV')
INSERT INTO Strassenkategorie_RAS_L VALUES (31,'C-I')
INSERT INTO Strassenkategorie_RAS_L VALUES (32,'C-II')
INSERT INTO Strassenkategorie_RAS_L VALUES (33,'C-III')
INSERT INTO Strassenkategorie_RAS_L VALUES (34,'C-IV')
INSERT INTO Strassenkategorie_RAS_L VALUES (42,'D-II')
INSERT INTO Strassenkategorie_RAS_L VALUES (43,'D-III')
INSERT INTO Strassenkategorie_RAS_L VALUES (44,'D-IV')
INSERT INTO Strassenkategorie_RAS_L VALUES (45,'D-V')
INSERT INTO Strassenkategorie_RAS_L VALUES (53,'E-III')
INSERT INTO Strassenkategorie_RAS_L VALUES (54,'E-IV')
INSERT INTO Strassenkategorie_RAS_L VALUES (55,'E-V')
INSERT INTO Strassenkategorie_RAS_L VALUES (56,'E-VI')
INSERT INTO Strassenkategorie_RAS_L VALUES (99,'Sonstiges')

CREATE TABLE Geschwindigkeitsband (
   Geschwindigkeitsband_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Geschwindigkeitsband_ID) REFERENCES allgemeine_Eigenschaften
)

CREATE TABLE Geschwindigkeitsb__hat_V_Koor (
   Geschwindigkeitsband
      INTEGER NOT NULL REFERENCES Geschwindigkeitsband,
   V_Koor
      INTEGER NOT NULL REFERENCES V_Koor,
   folgt_auf_V_Koor
      INTEGER REFERENCES V_Koor
)

CREATE TABLE V_Koor (
   V_Koor_ID
      INTEGER NOT NULL PRIMARY KEY,
   Station
      REAL NOT NULL, -- Meter
   Geschwindigkeit
      INTEGER NOT NULL, -- Stundenkilometer
   CHECK ( Geschwindigkeit >= 0 )
)

CREATE TABLE Sichtweiten (
   Sichtweiten_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Sichtweiten_ID) REFERENCES allgemeine_Eigenschaften,
   gehoert_zu_Achse
      INTEGER NOT NULL REFERENCES Achse,
   hat_Fahrspur
      INTEGER REFERENCES Spur_aus_Ausgangsdaten,
   hat_Gegenspur
      INTEGER REFERENCES Spur_aus_Ausgangsdaten,
   gehoert_zu_Trasse
      INTEGER NOT NULL REFERENCES Trasse
)

CREATE TABLE Sichtweiten__hat_SW_Koor (
   Sichtweiten
      INTEGER NOT NULL REFERENCES Sichtweiten,
   SW_Koor
      INTEGER NOT NULL REFERENCES SW_Koor,
   folgt_auf_SW_Koor
      INTEGER REFERENCES SW_Koor
)

CREATE TABLE SW_Koor (
   SW_Koor_ID
      INTEGER NOT NULL PRIMARY KEY,
   Station
      REAL NOT NULL, -- Meter
   Sichtweite_erforderlich
      REAL NOT NULL, -- Meter
   Sichtweite_vorhanden
      REAL NOT NULL -- Meter
)

CREATE TABLE allgemeine_Eigenschaften (
   allgemeine_Eigenschaften_ID
      INTEGER NOT NULL PRIMARY KEY,
   Bezeichnung
      VARCHAR(255),
   fachliche_Bedeutung
      VARCHAR(255) NOT NULL
)

CREATE TABLE allgemeine_Eigenschaften__Info (
   allgemeine_Eigenschaften
      INTEGER NOT NULL REFERENCES allgemeine_Eigenschaften,
   Informationstext
      VARCHAR(255) NOT NULL
)

